<template>
	<HMContainer type="card">
		<template #header>
			<el-form ref="queryFormRef" :inline="true" :model="queryParams">
				<el-form-item label="名称" prop="group_name">
					<el-input v-model="queryParams.group_name" style="width: 226.4px" placeholder="名称" clearable />
				</el-form-item>

				<el-form-item>
					<el-button type="primary" icon="ele-Search" @click="handleQueryTable"> 查询 </el-button>
					<el-button icon="ele-Refresh" @click="resetQuery">重置 </el-button>
					<!-- <el-button icon="ele-Plus" @click="openOptDlg()"> 添加 </el-button> -->
				</el-form-item>
			</el-form>
		</template>
		<template #main>
			<div class="h-full" ref="chatDragContainerRef">
				<el-table
					v-loading="tableLoading"
					ref="draggableTableRef"
                    rowKey="group_id"
					class="h100"
                    :tree-props="{ children: 'children', hasChildren: 'hasChildren' }"
					border
					:row-class-name="isDragStatus ? 'cursor-move' : 'cursor-pointer'"
					:data="displayTableData"
					highlight-current-row
				>
					<!-- <el-table-column type="expand" fixed="left">
						<template #default="scope">
							<div class="ml-16">
								<h3>指标页面</h3>
								<div v-if="scope.row.supervisor">
									<div class="py-3">
										页面提示词：<span class="">{{ scope.row.supervisor.prompt }}</span>
									</div>
									<el-table class="w-2/3" :data="scope.row.supervisor.args" border>
										<el-table-column prop="name" label="名称" show-overflow-tooltip> </el-table-column>
										<el-table-column prop="prompt" label="参数提示词" show-overflow-tooltip> </el-table-column>
										<el-table-column prop="check" label="缺省值" show-overflow-tooltip> </el-table-column>
									</el-table>
								</div>
							</div>
						</template>
					</el-table-column> -->

					<el-table-column prop="group_name" label="名称" width="300" fixed="left" show-overflow-tooltip> </el-table-column>

					<el-table-column label="说明" prop="group_title" show-overflow-tooltip> </el-table-column>

					<el-table-column label="操作" width="200" fixed="right" show-overflow-tooltip>
						<template #default="scope">
							<!-- <div class="space-x-3 items-center flex">
								<el-tooltip effect="dark" content="查看提示词" placement="top">
									<i class="ywifont ywicon-tishici !text-[21px] text-blue-400 cursor-pointer" @click="openCopyPrompt(scope.row)"></i>
								</el-tooltip>
								<el-tooltip effect="dark" content="查看指标名称" placement="top">
									<i
										class="ywifont ywicon-zhibiao !text-[17px] text-blue-400 cursor-pointer"
										@click="openMetricNameDlg(scope.row)"
									></i>
								</el-tooltip>

								<el-tooltip effect="dark" content="对话测试" placement="top">
									<i class="ywifont ywicon-ceshi !text-[20px] text-blue-400 cursor-pointer" @click="openChatTest(scope.row)"></i>
								</el-tooltip>

								
							</div> -->
						</template>
					</el-table-column>
				</el-table>
			</div>
		</template>

		<!-- <OptDlg v-model="optDlgIsShow" :item="optDlgMapRow" @insert="insertOpt" @update="updateOpt" :groupId="currentListID"></OptDlg> -->
		<!-- <MetricPrompt v-model="infoDlgIsShow" :metricItem="infoDlgMapRow"></MetricPrompt>
		<MetricName v-model="metricNameIsShow" :metricItem="metricNameMapRow"></MetricName> -->
	</HMContainer>
</template>

<script setup lang="ts">
import { useDraggable } from '@vueuse/core';

import { onMounted, ref } from 'vue';
import { usePageDisplay } from '/@/hooks/usePageDisplay';
import { useQueryTable } from '/@/hooks/useQueryTable';
// import { useTableSort } from '/@/hooks/useTableSort';
// import { useValidateUniqueness } from '/@/hooks/useValidateUniqueness';
import { ElMessage } from 'element-plus';
import { nextTick } from 'vue';
import * as agentGroupApi from '/@/api/ai/agentGroup';
import { updatePublishStatus } from '/@/api/supervisorAdmin';
import Chat from '/@/components/chat/Chat.vue';
import { useCompRef } from '/@/utils/types';

import axios, { CancelTokenSource } from 'axios';
import { SupervisorPublished, supervisorPublishedMap } from '../../lowCode/sqlAmis/types';
// import MetricName from './optDlg/MetricName.vue';
// import MetricPrompt from './optDlg/MetricPrompt.vue';
import HMContainer from '/@/components/layout/HMContainer.vue';
import { convertListToTree } from '/@/utils/util';

//#region ====================== 表格数据，table init ======================
const tableLoading = ref(false);
const tableData = ref([]);
const isDragStatus = ref(false);
const getTableData = async () => {
	const res = await agentGroupApi.getAgentGroupTreeByPost();

	tableData.value = convertListToTree(res?.groups ?? [], {
		ID: 'group_id',
		ParentID: 'p_group_id',
		Children: 'children',
	});
};
//#endregion

//#region ====================== 表格查询、排序，search form init ======================

const queryParams = ref({
	group_name: '',
});
const { resetQuery, handleQueryTable, displayTableData } = useQueryTable(tableData, queryParams, () => {
	displayTableData.value = tableData.value;
},false,true);

//#endregion

//#region ====================== 查询快捷键 ======================
const queryFormRef = ref(null);
const pressEnterSearch = (ev: KeyboardEvent) => {
	if (ev.key === 'Enter') {
		handleQueryTable();
	}
};
usePageDisplay(
	() => {
		queryFormRef.value?.$el?.addEventListener('keypress', pressEnterSearch);
	},
	() => {
		queryFormRef.value?.$el?.removeEventListener('keypress', pressEnterSearch);
	}
);
//#endregion

//#region ====================== 添加修改操作 ======================
const optDlgIsShow = ref(false);
const optDlgMapRow = ref(null);
const openOptDlg = (row?: any) => {
	optDlgMapRow.value = row;
	optDlgIsShow.value = true;
};

const updateOpt = (formValue) => {
	const foundIndex = tableData.value.findIndex((item) => item.id === formValue.id);
	if (foundIndex > -1) {
		tableData.value[foundIndex] = {
			...tableData.value[foundIndex],
			...formValue,
		};
	}
};

const insertOpt = (newData) => {
	tableData.value.unshift({ ...newData, published: SupervisorPublished.N });
};
//#endregion

const updatePublishedById = (id: string, published: SupervisorPublished) => {
	const row = tableData.value.find((item) => item.id === id);
	if (row) {
		row.published = published;
	}
};
//#region ====================== 改变发布状态 ======================
const publishStatusChange = async (published: SupervisorPublished, id, index) => {
	const res = await updatePublishStatus(
		{
			id: id,
			publish: published,
		},
		{
			loading: false,
		}
	);
	const origin = published === SupervisorPublished.Y ? SupervisorPublished.N : SupervisorPublished.Y;
	const final = res.publish ?? origin;
	if (final === origin) {
		ElMessage.warning('操作失败' + (res.fail_msg ? `：${res.fail_msg}` : ''));
		return;
	}

	tableData.value[index].published = final;

	published === SupervisorPublished.Y ? ElMessage.success('发布成功') : ElMessage.info('已取消发布');
};
//#endregion

//#region ====================== Chat 测试 ======================

const chatRef = useCompRef(Chat);
const chatTestMapRow = ref(null);
const chatTestIsShow = ref(false);
const openChatTest = (row) => {
	chatTestMapRow.value = row;
	chatTestIsShow.value = true;
	nextTick(() => {
		chatRef.value.clear();
		// setTimeout(() => {
		// 	chatRef.value.autoSend(row.title);
		// }, 30);
	});
};

const closeChatTest = () => {
	chatTestMapRow.value = null;
	chatTestIsShow.value = false;
};

const draggableChatRef = ref<HTMLElement | null>(null);
const chatDragHandlerRef = ref<HTMLDivElement>(null);
const chatDragContainerRef = ref<HTMLDivElement>(null);

// `style` will be a helper computed for `left: ?px; top: ?px;`
const { x, y, style } = useDraggable(draggableChatRef, {
	handle: chatDragHandlerRef,
	initialValue: {
		x: document.body.clientWidth / 2 - 350,
		y: document.body.clientHeight / 2 - 400,
	},
});

const questionAi = async (text, sourceObj: { source: CancelTokenSource }) => {
	const currentSource = axios.CancelToken.source();
	sourceObj.source = currentSource;
	const res = await agentGroupApi.checkMetricAgentValidateByPost(
		{
			agent_id: chatTestMapRow.value.id,
			question: text,
		},
		{
			loading: false,
			cancelToken: currentSource.token,
		}
	);
	return res;
};
//#endregion

//#region ====================== 更新发布状态 ======================
// useUpdateData({
// 	event: 'supervisor.publish',
// 	updateFun({ id, published }) {
// 		updatePublishedById(id, published);
// 	},
// });
//#endregion
//#region ====================== prompt查看 ======================
const infoDlgIsShow = ref(false);
const infoDlgMapRow = ref([]);
const openCopyPrompt = (row) => {
	infoDlgMapRow.value = row;
	infoDlgIsShow.value = true;
};
//#endregion
//#region ====================== 指标名称列表查看 ======================
const metricNameIsShow = ref(false);
const metricNameMapRow = ref([]);
const openMetricNameDlg = (row) => {
	metricNameMapRow.value = row;
	metricNameIsShow.value = true;
};
//#endregion
onMounted(() => {
	getTableData();
});
</script>
<style scoped lang="scss"></style>
